@@ -8,6 +8,11 @@ type QuayRegistryContext struct {
 	ServerHostname       string
 	BuildManagerHostname string
 
+	// TLS
+	ClusterWildcardCert []byte
+	TLSCert             []byte
+	TLSKey              []byte
+
 	// Object Storage
 	SupportsObjectStorage    bool
 	ObjectStorageInitialized bool
@@ -16,9 +21,16 @@ type QuayRegistryContext struct {
 	StorageAccessKey         string
 	StorageSecretKey         string
 
+	// Monitoring
+	SupportsMonitoring bool
+
 	// Secret Keys
 	DatabaseSecretKey string
 	SecretKey         string
+
+	// Database
+	DbUri    string
+	DbRootPw string
 }
 
 // NewQuayRegistryContext returns a fresh context for reconciling a `QuayRegistry`.
