@@ -5,8 +5,8 @@ import (
 	"encoding/base64"
 	"errors"
 	"fmt"
-	"net"
 	"net/url"
+	"os"
 	"strings"
 
 	"github.com/quay/clair/v4/config"
@@ -19,7 +19,6 @@ import (
 	"github.com/quay/config-tool/pkg/lib/fieldgroups/securityscanner"
 	"github.com/quay/config-tool/pkg/lib/shared"
 	"gopkg.in/yaml.v3"
-	"k8s.io/client-go/util/cert"
 
 	v1 "github.com/quay/quay-operator/apis/quay/v1"
 	quaycontext "github.com/quay/quay-operator/pkg/context"
@@ -29,8 +28,7 @@ import (
 var underTest = false
 
 const (
-	secretKeySecretName = "quay-registry-managed-secret-keys"
-	secretKeyLength     = 80
+	secretKeyLength = 80
 
 	clairService = "clair-app"
 	// FIXME: Ensure this includes the `QuayRegistry` name prefix when we add `builder` managed component.
@@ -38,9 +36,9 @@ const (
 )
 
 // FieldGroupFor generates and returns the correct config field group for the given component.
-func FieldGroupFor(ctx *quaycontext.QuayRegistryContext, component string, quay *v1.QuayRegistry) (shared.FieldGroup, error) {
+func FieldGroupFor(ctx *quaycontext.QuayRegistryContext, component v1.ComponentKind, quay *v1.QuayRegistry) (shared.FieldGroup, error) {
 	switch component {
-	case "clair":
+	case v1.ComponentClair:
 		fieldGroup, err := securityscanner.NewSecurityScannerFieldGroup(map[string]interface{}{})
 		if err != nil {
 			return nil, err
@@ -59,7 +57,7 @@ func FieldGroupFor(ctx *quaycontext.QuayRegistryContext, component string, quay
 		fieldGroup.SecurityScannerV4PSK = psk
 
 		return fieldGroup, nil
-	case "redis":
+	case v1.ComponentRedis:
 		fieldGroup, err := redis.NewRedisFieldGroup(map[string]interface{}{})
 		if err != nil {
 			return nil, err
@@ -75,24 +73,16 @@ func FieldGroupFor(ctx *quaycontext.QuayRegistryContext, component string, quay
 		}
 
 		return fieldGroup, nil
-	case "postgres":
+	case v1.ComponentPostgres:
 		fieldGroup, err := database.NewDatabaseFieldGroup(map[string]interface{}{})
 		if err != nil {
 			return nil, err
 		}
-		user := quay.GetName() + "-quay-database"
-		name := quay.GetName() + "-quay-database"
-		host := strings.Join([]string{quay.GetName(), "quay-database"}, "-")
-		port := "5432"
-		password, err := generateRandomString(32)
-		if err != nil {
-			return nil, err
-		}
 
-		fieldGroup.DbUri = fmt.Sprintf("postgresql://%s:%s@%s:%s/%s", user, password, host, port, name)
+		fieldGroup.DbUri = ctx.DbUri
 
 		return fieldGroup, nil
-	case "objectstorage":
+	case v1.ComponentObjectStorage:
 		fieldGroup := &distributedstorage.DistributedStorageFieldGroup{
 			FeatureProxyStorage:                true,
 			DistributedStoragePreference:       []string{"local_us"},
@@ -114,15 +104,17 @@ func FieldGroupFor(ctx *quaycontext.QuayRegistryContext, component string, quay
 		}
 
 		return fieldGroup, nil
-	case "route":
+	case v1.ComponentRoute:
+		// sets tls termination in the load balancer if no cert has been provided.
+		terminateExternally := len(ctx.TLSCert) == 0 && len(ctx.TLSKey) == 0
 		fieldGroup := &hostsettings.HostSettingsFieldGroup{
-			ExternalTlsTermination: false,
+			ExternalTlsTermination: terminateExternally,
 			PreferredUrlScheme:     "https",
 			ServerHostname:         ctx.ServerHostname,
 		}
 
 		return fieldGroup, nil
-	case "mirror":
+	case v1.ComponentMirror:
 		fieldGroup := &repomirror.RepoMirrorFieldGroup{
 			FeatureRepoMirror:   true,
 			RepoMirrorInterval:  30,
@@ -130,21 +122,33 @@ func FieldGroupFor(ctx *quaycontext.QuayRegistryContext, component string, quay
 		}
 
 		return fieldGroup, nil
-	case "horizontalpodautoscaler":
+	case v1.ComponentHPA:
+		return nil, nil
+	case v1.ComponentMonitoring:
+		return nil, nil
+	case v1.ComponentTLS:
 		return nil, nil
 	default:
-		return nil, errors.New("unknown component: " + component)
+		return nil, errors.New("unknown component: " + string(component))
 	}
 }
 
 // BaseConfig returns a minimum config bundle with values that Quay doesn't have defaults for.
 func BaseConfig() map[string]interface{} {
+	registryTitle := "Quay"
+	enterpriseLogoURL := "/static/img/quay-horizontal-color.svg"
+	if os.Getenv("QUAY_DEFAULT_BRANDING") == "redhat" {
+		registryTitle = "Red Hat Quay"
+		enterpriseLogoURL = "/static/img/RH_Logo_Quay_Black_UX-horizontal.svg"
+	}
+
 	return map[string]interface{}{
+		"SETUP_COMPLETE":                     true,
 		"FEATURE_MAILING":                    false,
-		"REGISTRY_TITLE":                     "Red Hat Quay",
-		"REGISTRY_TITLE_SHORT":               "Red Hat Quay",
+		"REGISTRY_TITLE":                     registryTitle,
+		"REGISTRY_TITLE_SHORT":               registryTitle,
 		"AUTHENTICATION_TYPE":                "Database",
-		"ENTERPRISE_LOGO_URL":                "/static/img/RH_Logo_Quay_Black_UX-horizontal.svg",
+		"ENTERPRISE_LOGO_URL":                enterpriseLogoURL,
 		"DEFAULT_TAG_EXPIRATION":             "2w",
 		"ALLOW_PULLS_WITHOUT_STRICT_LOGGING": false,
 		"TAG_EXPIRATION_OPTIONS":             []string{"2w"},
@@ -155,12 +159,11 @@ func BaseConfig() map[string]interface{} {
 	}
 }
 
-// EnsureTLSFor checks if given TLS cert/key pair are valid for the Quay registry to use for secure communication with clients,
-// and generates a TLS certificate/key pair if they are not provided.
-func EnsureTLSFor(ctx *quaycontext.QuayRegistryContext, quay *v1.QuayRegistry, tlsCert, tlsKey []byte) ([]byte, []byte, error) {
+// EnsureTLSFor checks if given TLS cert/key pair are valid for the Quay registry to use for secure communication with clients.
+func EnsureTLSFor(ctx *quaycontext.QuayRegistryContext, quay *v1.QuayRegistry) ([]byte, []byte, error) {
 	fieldGroup, err := FieldGroupFor(ctx, "route", quay)
 	if err != nil {
-		return tlsCert, tlsKey, err
+		return ctx.TLSCert, ctx.TLSKey, err
 	}
 
 	routeFieldGroup := fieldGroup.(*hostsettings.HostSettingsFieldGroup)
@@ -174,48 +177,54 @@ func EnsureTLSFor(ctx *quaycontext.QuayRegistryContext, quay *v1.QuayRegistry, t
 		hosts = append(hosts, strings.Split(ctx.BuildManagerHostname, ":")[0])
 	}
 
-	if tlsCert == nil && tlsKey == nil {
-		return cert.GenerateSelfSignedCertKey(routeFieldGroup.ServerHostname, []net.IP{}, hosts)
+	fgn, err := v1.FieldGroupNameFor(v1.ComponentRoute)
+	if err != nil {
+		return nil, nil, fmt.Errorf("error getting group name for component: %w", err)
 	}
 
-	for _, host := range hosts {
-		if valid, validationErr := shared.ValidateCertPairWithHostname(tlsCert, tlsKey, host, fieldGroupNameFor("route")); !valid {
-			return nil, nil, fmt.Errorf("provided certificate/key pair not valid for host '%s': %s", host, validationErr.String())
+	if ctx.TLSCert != nil && ctx.TLSKey != nil {
+		for _, host := range hosts {
+			if valid, validationErr := shared.ValidateCertPairWithHostname(ctx.TLSCert, ctx.TLSKey, host, fgn); !valid {
+				return nil, nil, fmt.Errorf("provided certificate/key pair not valid for host '%s': %s", host, validationErr.String())
+			}
 		}
 	}
 
-	return tlsCert, tlsKey, nil
+	return ctx.TLSCert, ctx.TLSKey, nil
 }
 
 // ContainsComponentConfig accepts a full `config.yaml` and determines if it contains
 // the fieldgroup for the given component by comparing it with the fieldgroup defaults.
 // TODO: Replace this with function from `config-tool` library once implemented.
-func ContainsComponentConfig(fullConfig map[string]interface{}, component string) (bool, error) {
+func ContainsComponentConfig(fullConfig map[string]interface{}, certs map[string][]byte, component v1.Component) (bool, error) {
 	fields := []string{}
 
-	switch component {
-	case "clair":
+	switch component.Kind {
+	case v1.ComponentClair:
 		fields = (&securityscanner.SecurityScannerFieldGroup{}).Fields()
-	case "postgres":
+	case v1.ComponentPostgres:
 		fields = (&database.DatabaseFieldGroup{}).Fields()
-	case "redis":
+	case v1.ComponentRedis:
 		fields = (&redis.RedisFieldGroup{}).Fields()
-	case "objectstorage":
+	case v1.ComponentObjectStorage:
 		fields = (&distributedstorage.DistributedStorageFieldGroup{}).Fields()
-	case "horizontalpodautoscaler":
+	case v1.ComponentHPA:
 		// HorizontalPodAutoscaler has no associated config fieldgroup.
 		return false, nil
-	case "mirror":
+	case v1.ComponentMirror:
 		fields = (&repomirror.RepoMirrorFieldGroup{}).Fields()
-	case "route":
-		for _, field := range (&hostsettings.HostSettingsFieldGroup{}).Fields() {
-			// SERVER_HOSTNAME is a special field which we allow when using managed `route` component.
-			if field != "SERVER_HOSTNAME" {
-				fields = append(fields, field)
-			}
+	case v1.ComponentRoute:
+		fields = (&hostsettings.HostSettingsFieldGroup{}).Fields()
+	case v1.ComponentMonitoring:
+		return false, nil
+	case v1.ComponentTLS:
+		_, keyPresent := certs["ssl.key"]
+		_, certPresent := certs["ssl.cert"]
+		if certPresent && keyPresent {
+			return true, nil
 		}
 	default:
-		panic("unknown component: " + component)
+		panic("unknown component: " + component.Kind)
 	}
 
 	// FIXME: Only checking for the existance of a single field
@@ -228,31 +237,10 @@ func ContainsComponentConfig(fullConfig map[string]interface{}, component string
 	return false, nil
 }
 
-func fieldGroupNameFor(component string) string {
-	switch component {
-	case "clair":
-		return "SecurityScanner"
-	case "postgres":
-		return "Database"
-	case "redis":
-		return "Redis"
-	case "objectstorage":
-		return "DistributedStorage"
-	case "route":
-		return "HostSettings"
-	case "mirror":
-		return "RepoMirror"
-	case "horizontalpodautoscaler":
-		return ""
-	default:
-		panic("unknown component: " + component)
-	}
-}
-
 // componentConfigFilesFor returns specific config files for managed components of a Quay registry.
-func componentConfigFilesFor(component string, quay *v1.QuayRegistry, configFiles map[string][]byte) (map[string][]byte, error) {
+func componentConfigFilesFor(qctx *quaycontext.QuayRegistryContext, component v1.ComponentKind, quay *v1.QuayRegistry, configFiles map[string][]byte) (map[string][]byte, error) {
 	switch component {
-	case "postgres":
+	case v1.ComponentPostgres:
 		dbConfig, ok := configFiles["postgres.config.yaml"]
 		if !ok {
 			return nil, fmt.Errorf("cannot generate managed component config file for `postgres` if `postgres.config.yaml` is missing")
@@ -271,10 +259,7 @@ func componentConfigFilesFor(component string, quay *v1.QuayRegistry, configFile
 		databaseUsername := dbURI.User.Username()
 		databasePassword, _ := dbURI.User.Password()
 		databaseName := dbURI.Path[1:]
-		databaseRootPassword, err := generateRandomString(32)
-		if err != nil {
-			return nil, err
-		}
+		databaseRootPassword := qctx.DbRootPw
 
 		return map[string][]byte{
 			"database-username":      []byte(databaseUsername),
@@ -282,7 +267,7 @@ func componentConfigFilesFor(component string, quay *v1.QuayRegistry, configFile
 			"database-name":          []byte(databaseName),
 			"database-root-password": []byte(databaseRootPassword),
 		}, nil
-	case "clair":
+	case v1.ComponentClair:
 		quayHostname := ""
 		if v1.ComponentIsManaged(quay.Spec.Components, "route") {
 			config := decode(configFiles["route.config.yaml"])
@@ -343,7 +328,6 @@ func clairConfigFor(quay *v1.QuayRegistry, quayHostname, preSharedKey string) []
 			DeliveryInterval: "1m",
 			PollInterval:     "5m",
 			Webhook: &webhook.Config{
-				// NOTE: This can't be the in-cluster service hostname because the `passthrough` TLS certs are only valid for external `SERVER_HOSTNAME`.
 				Target:   "https://" + quayHostname + "/secscan/notification",
 				Callback: "http://" + quay.GetName() + "-" + clairService + "/notifier/api/v1/notifications",
 			},
